handle_log

Function handle_log 

fn handle_log(args: &Log, main_epoch: &mut EpochConfig) -> Result<(), AppError>
Show a log of all epochs up to the current one.

The function collects the identifiers of all epochs that are less than or equal to the currently active epoch (main_epoch.epoch_id), sorts them, and then asks the configuration to log the elements up to the supplied limit. The log is written by the underlying EpochConfig::log_elements implementation.

This helper is internal to the epoch sub-command.