fn handle_next(
_args: &Next,
main_epoch: &mut EpochConfig,
) -> Result<(), AppError>Expand description
Handle the next sub-command.
Advances the epoch to the next scheduled event. If the current configuration contains any epochs with an identifier larger than the current one, an error is returned - otherwise the next epoch is computed.
Arguments
main_epoch- mutable reference to the currentEpochConfig(thecli_epoch::Nextargument is unused).
Returns
Ok(())if the next epoch was successfully computed.Err(AppError::Epoch(EpochError::FutureEpochExist))if there are no future epochs to advance to.